@@ -5,7 +5,7 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * Copyright (C) 1998 - 2005, Daniel Stenberg, <daniel@haxx.se>, et al.
+ * Copyright (C) 1998 - 2006, Daniel Stenberg, <daniel@haxx.se>, et al.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution. The terms
@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: sockfilt.c,v 1.21 2006-07-19 15:28:30 yangtse Exp $
+ * $Id: sockfilt.c,v 1.26 2006-10-27 03:47:58 yangtse Exp $
  ***************************************************************************/
 
 /* Purpose
@@ -119,7 +119,7 @@ static void lograw(unsigned char *buffer, ssize_t len)
       optr += 2;
       break;
     default:
-      sprintf(optr, "%c", (isgraph(ptr[i]) || ptr[i]==0x20) ?ptr[i]:'.');
+      sprintf(optr, "%c", (ISGRAPH(ptr[i]) || ptr[i]==0x20) ?ptr[i]:'.');
       width++;
       optr++;
       break;
@@ -238,7 +238,7 @@ static int juggle(curl_socket_t *sockfdp,
 
   do {
     rc = select(maxfd + 1, &fds_read, &fds_write, &fds_err, &timeout);
-  } while((rc == -1) && (ourerrno() == EINTR));
+  } while((rc == -1) && (our_sockerrno() == EINTR));
 
   switch(rc) {
   case -1:
@@ -552,7 +552,7 @@ int main(int argc, char *argv[])
     }
   }
 
-#if defined(WIN32) && !defined(__GNUC__) || defined(__MINGW32__)
+#ifdef WIN32
   win32_init();
   atexit(win32_cleanup);
 #else
